`LicenseRef-PdfiumThirdParty` applies for the PDFium binaries that are deployed to end users without being part of the repository (`pdfium` / `pdfium.dll` / `pdfium.dylib`). It consists of multiple licenses for third-party components of PDFium.
